@@ -2,8 +2,8 @@
                           cencrypt.h  -  description
                              -------------------
     begin                : Sat Sep 29 2001
-    copyright            : (C) 2001 by Mathias Kster
-    email                : mathen@ketelhot.de
+    copyright            : (C) 2001-2003 by Mathias Kster
+    email                : mathen@users.berlios.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,13 +18,13 @@
 #ifndef CENCRYPT_H
 #define CENCRYPT_H
 
-#include <dclib/dcos.h>
-#include <dclib/cstring.h>
-
 /**
   *@author Mathias Kster
   */
 
+#include <dclib/dcos.h>
+#include <dclib/core/cstring.h>
+
 class DLL_EXPORT CEncrypt {
 public: 
 	CEncrypt();
@@ -34,6 +34,10 @@ public:
 	void Encrypt( CString s, CString & d );
 	/** */
 	void Encode( int c, CString & d );
+	/** */
+	CString Encode( CString s );
+	/** */
+	CString Decode( CString s );
 };
 
 #endif
